GetCheckLog

Struct GetCheckLog 

pub struct GetCheckLog {
    pub uri: DocumentUri,
}
Serialized arguments for the get_check_log server function.

Fields

uri: DocumentUri

Methods from Deref<Target = DocumentUri>

pub fn module_uri_from(&self, name: &str) -> Result<ModuleUri, UriParseError>

Returns the URI of a module within this document

If the name’s first segment is equal to the document’s name, the module’s [PathUri] and first name are those of the document. Otherwise, the document’s name is appended to the path, and the module’s name is the one provided.

Errors

if the provided name is not a valid module name (e.g. contains illegal characters or empty segments).

Examples
let doc_uri: DocumentUri = "http://example.com?a=archive&p=path&d=math&l=en".parse().unwrap();
let module_uri = doc_uri.module_uri_from("math").unwrap();
assert_eq!(module_uri.to_string(),"http://example.com?a=archive&p=path&m=math");
let module_uri = doc_uri.module_uri_from("algebra").unwrap();
assert_eq!(module_uri.to_string(),"http://example.com?a=archive&p=path/math&m=algebra");
let module_uri = doc_uri.module_uri_from("math/algebra").unwrap();
assert_eq!(module_uri.to_string(),"http://example.com?a=archive&p=path&m=math/algebra");
let module_uri = doc_uri.module_uri_from("algebra/groups").unwrap();
assert_eq!(module_uri.to_string(),"http://example.com?a=archive&p=path/math&m=algebra/groups");